function vlna1_demo(A,T,lambda)
% function vlna1_demo(A,T,lambda)
% A - amplituda
% T - perioda
% lambda - vlnova delka
%
% priklad pouziti: vlna1_demo(1,1,1)
%

x=linspace(0,3*lambda,201); % zobrazi se tri vlnove delky
y0=zeros(size(x));          % nulova funkce na zacatku
omega=2*pi/T;               % uhlova rychlost
c=lambda/T;                 % rychlost sireni vlny (take c=lambda*omega/(2pi) )
t=0;
arg=x-c*t;
y=y0;
plot(x,y);
axis([x(1),x(end),-2*A,2*A]);
disp('Neco stiskni!')
pause
for t=linspace(0,10*T,401)
    arg=omega*(t-x/c);
    arg=max(arg,0);
    y=A*sin(arg);
    plot(x,y);
    axis([x(1),x(end),-2*A,2*A]);
    pause(0.1);
end